@@ -86,7 +86,8 @@ main(int argc, char **argv)
 	while (fread(&c, 1, 1, infile) == 1) {
 		_vte_buffer_append(buffer, &c, 1);
 	}
-	_vte_iso2022_process(subst, buffer, array);
+	_vte_iso2022_process(subst, buffer->bytes,
+			_vte_buffer_length(buffer), array);
 
 	i = 0;
 	while (i <= array->len) {
@@ -147,7 +148,7 @@ main(int argc, char **argv)
 			}
 		}
 		if (values != NULL) {
-			_vte_matcher_free_params_array(values);
+			_vte_matcher_free_params_array(matcher, values);
 		}
 		g_print(")\n");
 		i += l;
